@@ -1,7 +1,7 @@
 /*
  * This file is part of nzbget. See <http://nzbget.net>.
  *
- * Copyright (C) 2012-2016 Andrey Prygunkov <hugbug@users.sourceforge.net>
+ * Copyright (C) 2012-2019 Andrey Prygunkov <hugbug@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,6 +42,7 @@ var Upload = (new function($)
 	var needRefresh = false;
 	var failure_message = null;
 	var url = '';
+	var urlInfo;
 
 	this.init = function()
 	{
@@ -193,7 +194,6 @@ var Upload = (new function($)
 
 	function addFiles(selectedFiles)
 	{
-		var list = '';
 		for (var i = 0; i<selectedFiles.length; i++)
 		{
 			var file = selectedFiles[i];
@@ -211,7 +211,7 @@ var Upload = (new function($)
 			var info = { name: name, ext: ext, password: '', dupekey: '', dupescore: 0 };
 			infos.push(info);
 		}
-		$('#AddDialog_Files').show();
+		$('#AddDialog_Files,#AddDialog_RenameTip').show();
 		$('#AddDialog_FilesHelp').hide();
 	}
 
@@ -222,13 +222,17 @@ var Upload = (new function($)
 	
 	this.renameClick = function(no)
 	{
-		var file = files[no];
 		var info = infos[no];
 		AddParamDialog.showModal(info, function() {
 			$('#AddDialog_File' + no).html(Util.formatNZBName(info.name + info.ext));
 		});
 	}
 
+	this.renameURLClick = function(no)
+	{
+		AddParamDialog.showModal(urlInfo, function(){});
+	}
+
 	function showModal(droppedFiles)
 	{
 		Refresher.pause();
@@ -249,6 +253,7 @@ var Upload = (new function($)
 
 		files = [];
 		filesSuccess = [];
+		urlInfo = { name: '', password: '', dupekey: '', dupescore: 0 };
 
 		if (droppedFiles)
 		{
@@ -353,7 +358,7 @@ var Upload = (new function($)
 			var filename = info.name + info.ext;
 			var addPaused = $('#AddDialog_Paused').is(':checked');
 			var dupeMode = $('#AddDialog_DupeForce').is(':checked') ? "FORCE" : "SCORE";
-			var params = info.password === '' ? [] : [{'*Unpack:password' : info.password}];
+			var params = info.password === '' ? [] : [{'*Unpack:Password' : info.password}];
 			RPC.call('append', [filename, base64str, category, priority, false, addPaused, info.dupekey, info.dupescore, dupeMode, params], fileCompleted, fileFailure);
 		};
 
@@ -394,12 +399,19 @@ var Upload = (new function($)
 		$('#AddDialog_URLLabel img').show();
 		$('#AddDialog_URLLabel i').hide();
 
+		var name = urlInfo.name.toLowerCase();
+		if (name !== '' && !(Util.endsWith(name, '.nzb') || Util.endsWith(name, '.zip') ||
+			Util.endsWith(name, '.7z') || Util.endsWith(name, '.rar') || Util.endsWith(name, '.tar.gz')))
+		{
+			urlInfo.name += '.nzb';
+		}
+		
 		var category = $('#AddDialog_Category').val();
 		var priority = parseInt($('#AddDialog_Priority').val());
 		var addPaused = $('#AddDialog_Paused').is(':checked');
 		var dupeMode = $('#AddDialog_DupeForce').is(':checked') ? "FORCE" : "SCORE";
-
-		RPC.call('append', ['', url, category, priority, false, addPaused, '', 0, dupeMode], urlCompleted, urlFailure);
+		var params = urlInfo.password === '' ? [] : [{'*Unpack:Password' : urlInfo.password}];
+		RPC.call('append', [urlInfo.name, url, category, priority, false, addPaused, urlInfo.dupekey, urlInfo.dupescore, dupeMode, params], urlCompleted, urlFailure);
 	}
 
 	function urlCompleted(result)
